from configmanager.format_module_manager import ModuleManager

def test_inizialization() -> None:
    moduleManager = ModuleManager()
    assert moduleManager is not None


def test_collect_modules() -> None:
    moduleManager = ModuleManager()
    modules_in_file:list = ModuleManager.get_modules()
    assert len(modules_in_file) > 0



"""
@Author Marco A. Gallegos
@Date   2020/12/31
@Update 2020/12/31
@Description
    The config manager is a class to manage the configuration file by default in ~/.commitclirc
"""
import distutils.util
import os
import pathlib
import re

from configmanager.config import Configuration
from configmanager.format_module_manager import ModuleManager


class ConfigManager(object):
    # data
    # moduleManager:ModuleManager|None

    def __init__(
            self, file: str = '.commitclirc',
            config: Configuration = None,
            override_config:dict = None,
            moduleManager:ModuleManager = None,
            loadModuleManager:bool = False
        ) -> None:
        self._file:str = file
        self.config:Configuration|None = config
        self.regex_clave_valor = r'[\D]+[=]{1}[\w]+'
        self.pattern_regex_clave_valor = re.compile(self.regex_clave_valor)

        # some initial starts
        self.init_config(override_config=override_config)

        # module manager
        self.moduleManager:ModuleManager|None = None 
        if loadModuleManager is True and moduleManager is None:
            self.moduleManager = ModuleManager()
        elif loadModuleManager is False and moduleManager is not None:
            self.moduleManager = moduleManager



    def current_file(self) -> str:
        """this function return the fullpath of the file to store
        the configuration

        :return: string with the full path of the file to
        :rtype: str
        """
        global_file = f"{pathlib.Path.home()}/{self._file}"
        project_file = f"{pathlib.Path.cwd()}/{self._file}"
        return project_file if self.exist_file(project_file) else global_file

    def exist_file(self, file: str) -> bool:
        """this function returns a boolean value on true if the file
        to store the configuration

        :return: if the file exists on the filesystem
        :rtype: bool
        """
        exist = os.path.exists(file)
        return True if exist else False

    def stringline_to_key_value(self, string_line: str = "#comentario") -> str:
        """This functions returns the separated values by '=' of a string in 
        format 'some=other'

        :param string_line: a string in fomat 'some=other', defaults to "#comentario"
        :type string_line: str, optional
        :return: the values on left and right side of the '=' character
        :rtype: str, str
        """
        key, value = None, None
        match = re.fullmatch(self.pattern_regex_clave_valor, string_line)
        if match and type(string_line) == str and string_line:
            elements = string_line.split("=")
            key= elements[0]
            value= elements[1]
        return key, value

    def load_file(self, file: str) -> dict:
        """Method to convert the configuration file into a dictionary

        :return: dictionary with al the key value files in thee file
        :rtype: dict
        """
        current_file = file
        if self.exist_file(current_file):
            data_dict = {}
            file = open(current_file, 'r')
            file_text = file.readlines()
            file.close()
            for file_line in file_text:
                file_line = file_line.replace('\n', '')
                key, value = self.stringline_to_key_value(string_line=file_line)
                if value == "False" or value == "True" or value == "false" or value == "true":
                    value = bool(distutils.util.strtobool(value.lower()))
                if key is not None and value is not None:
                    data_dict[key] = value
            return data_dict
        else:
            return None

    def save_file(self) -> bool:
        """Method to save the current configuration into the configured file

        :return: True
        :rtype: bool
        """
        file = open(self.current_file(), 'w')
        file.write(self.config.get_configuration_file_string())
        file.close()
        return True

    def init_config(self, force_reload: bool = False, override_config: dict = None) -> bool:
        """Method to initialize the class, triggering the load of the file or load
        creating a defaul config and save it on the file.

        :return: boolean representing the previous existence of the config file
        :rtype: bool
        """
        if self.config is None:
            current_file = self.current_file()
            if self.exist_file(current_file):
                data = self.load_file(current_file)
                self.config = Configuration(config=data, override_config=override_config)
                return True
            else:
                self.config = Configuration(override_config=override_config)
                self.save_file()
                return False
        return False 

    def get_config(self, name: str) -> str or bool or None:
        if self.config is not None and self.config.config is not None and self.config.config[name] is not None:
            return self.config.config[name]
        else:
            return None
        return None



"""
@Author Marco A. Gallegos
@Date   2020/12/31
@Update 2020/12/31
@Description
    This file contains a class to abstract a commit message
"""
import inquirer
from commitcli.common import changes_choices_by_format, get_questions, get_preselected_questions, PreselectedQuestion

from configmanager.config_manager import ConfigManager
from configmanager.format_module_manager import ModuleConfig
import pendulum

class CommitMessage(object):
    """This clas is a abstraction of a commit message,
    this class must to generate a formatted commit string

    Args:
        object (object): base object from python
    """
    
    def __init__(
        self,
        format: str = "cc",
        configuration_manager: ConfigManager = ConfigManager(),
        tag: str = None,
        module: str = None,
        header: str = None,
        body: str = None,
        footer: str = None,
    ):
        """Constructor of the class

        Args:
            format (str, optional): format to use. Defaults to "odoo".
            tag (str, optional): tag for the commit string. Defaults to None.
            module (str, optional): module affected for the commit string. Defaults to None.
            header (str, optional): header for the commit string. Defaults to None.
            body (str, optional): body for the commit string. Defaults to None.
        """
        super()
        self.tag = tag
        self.module = module
        self.header = header
        self.body = body
        self.footer = footer
        self.config:ConfigManager = configuration_manager
        
        self.format = self.config.config.config['format']

        self.choices:dict[str,list[tuple]] = changes_choices_by_format


    def get_commit_string(self)->str:
        """Method to return the formathed commit string

        Returns:
            str: formatted commit string
        """
        if self.can_generate_string():
            if self.format == "odoo" or self.format not in self.config.config.supported_formats:
                return f"[{self.tag}] {self.module}: {self.header}\n\n{self.body}"
            elif self.format == "free":
                return f"{self.body}"
            elif self.format == "cc":
                return "{tag}{module}: {header}{body}{footer}".format(
                    tag=self.tag,
                    module= ( "" if not self.module else f"({self.module})"),
                    header= self.header,
                    body= ( "" if not self.body else f"\n\n{self.body}"),
                    footer= ( "" if not self.footer else f"\n\n{self.footer}"),
                )
            else:
                print("error creating commit string")
        else:
            print("we can not create commit")
        return None


    def set_answers(self, answers:dict):
        """Method to set the answers from the user

        Args:
            answers (dict): answers provided by the user
        """
        if answers:
            if self.format == 'odoo':
                self.tag = answers['tag']
                self.module = answers['module']
                self.header = answers['header']
                self.body = answers['body']
            elif self.format == 'free':
                self.body = answers['body']
            elif self.format == 'sgc':
                pass
            elif self.format == 'cc':
                self.tag = answers['tag']
                self.module = answers['module']
                self.header = answers['header']
                if 'body' in answers:
                    self.body = answers['body']
                if 'footer' in answers:
                    self.footer = answers['footer']
            return True
        else:
            return False


    def get_preselected_answers(self) -> list[dict]:
        """check for possible preselected answers according the current format, make quuestions if is needed"""
        preselected_answers:list[dict] = []
        
        preselected_questions:list[PreselectedQuestion] = get_preselected_questions(format=self.format)
        
        for preselected_question in preselected_questions:
            question = preselected_question.get_value(self.config.moduleManager) 
            if question :
                preselected_answers.append(question)
        
        return preselected_answers


    def get_answers(self):
        """Method to get the answers from the user
        1 - check for preselections
        2 - request filtered answers
        3 - set up all answers
        """
        # ------- automatic answers detection ----------

        # if we had preselected result then we can get them here
        preselected_answers:list[dict] = self.get_preselected_answers()
        # ------ automatic answers segregation and formating ---------
        request_optionals:bool = True if self.config.get_config("avoid_optionals") else False 
        
        preselected_answers_key_list:list[str] = [ list(key.keys())[0] for key in preselected_answers ]

        # ------ regular question prompting ------------

        normal_questions = get_questions(self.format, preselected_answers_key_list, request_optionals)

        normal_answers = inquirer.prompt(normal_questions[self.format])
        
        # print(normal_answers, preselected_answers)

        answers:dict = dict()
        for preselected_answer in preselected_answers:
            answers.update(preselected_answer)
        answers.update(normal_answers)
        
        # print(answers)

        if answers:
            # TODO: handle optional
            # if self.format in self.optional_questions and not request_optionals:
                # for question in self.optional_questions[self.format]:
                    # set_question = input(f"set the {question.name} (y,*): ")
                    # if set_question.lower() == 'y':
                        # temp_dict = inquirer.prompt({question})
                        # answers.update(temp_dict)
            # after optional question handling make a update
            self.set_answers(answers)


    def can_generate_string(self) -> bool:
        """Method to determinate if we can build the commit message
        for the selected format

        Returns:
            bool: true if we can build the string
        """
        if self.format == "odoo":
            return self.tag and self.module and self.header and self.body
        elif self.format == "free":
            return self.body
        elif self.format == "sgc":
            return False
        elif self.format == "cc":
            return self.tag and self.header
        else:
            return False
    

    def update_preselected_data(self):
        """Update modules file
        1 - get used module
        2 - get modules in file (in this point this module should exist in module manager)
        3 - search for our module inside the result
            3.1 -  if exist update counter and last used
            3.2 - if not exists addit to the list
                a - limit number of modules to write to 10
        4 - save the modules infomation
        """
        current_modules:list = self.config.moduleManager.get_modules()
        new_modules:list[ModuleConfig] = []
        current_date = pendulum.now()
        exist_in_module_list:bool = False

        modules_as_csv = ""
        
        if current_modules and len(current_modules) > 0:
            for module in current_modules:
                if module.name.lower() == self.module.lower():
                    module.last_used = current_date.int_timestamp
                    module.use_count += 1
                    exist_in_module_list = True
                new_modules.append(module)
        
        if exist_in_module_list is False:
            new_module = ModuleConfig(self.module, current_date.int_timestamp, current_date.int_timestamp, 1)
            new_modules.append(new_module)

        new_modules.sort(key=lambda module: module.last_used, reverse=True)

        new_modules = new_modules[0:9:1]

        for module in new_modules:
            modules_as_csv += f"{module.name},{module.date},{module.last_used},{module.use_count}\n"

        
        # overwrite file
        file = open(".ignore.commitcli_modules", "w")

        file.write(modules_as_csv)
        file.close()







from os import name
import inquirer
from configmanager.format_module_manager import ModuleManager, ModuleConfig

class PreselectedQuestion(object):

    def __init__(self, name:str, get_function) -> None:
        self.name:str = name
        self.get_value = get_function


def get_preselected_module(moduleManager:ModuleManager) -> dict[str, str]:
    """function to get the preselected Module"""
    # get module lis
    module_list:list[ModuleConfig] = moduleManager.get_modules()
    answer:dict = {}

    module_options_list = [
        ("No, let me write it", "no")
    ]
    
    if module_list and len(module_list) > 0:
        module_options_temporal_list = [ (x.name, x.name) for x in  module_list ]

        module_options_list += module_options_temporal_list
        
        # here we expect a array so we want make a questio
        questions = [
            inquirer.List(name="module", message="your module is here?", choices=module_options_list)
        ]

        answer = inquirer.prompt(questions)

    if answer and answer['module'] == 'no':
        answer.pop('module')
       
    return answer


changes_choices_by_format:dict[str,list[tuple]] = {
    "odoo": [
        (
            "IMP: for improvements: most of the changes done in development version are incremental improvements not related to another tag",
            "IMP"
        ),
        (
            "FIX: for bug fixes: mostly used in stable version but also valid if you are fixing a recent bug in development version",
            "FIX"
        ),
        (
            "ADD: for adding new modules",
            "ADD"
        ),
        (
            "REM: for removing resources: removing dead code, removing views, removing modules, …",
            "REM"
        ),
        (
            "REF: for refactoring: when a feature is heavily rewritten",
            "REF"
        ),
        (
            "MOV: for moving files: use git move and do not change content of moved file otherwise Git may loose track and history of the file; also used when moving code from one file to another",
            "MOV"
        ),
        (
            "REV for reverting commits: if a commit causes issues or is not wanted reverting it is done using this tag",
            "REV"
        ),
    ],
    "free":[

    ],
    "sgc":[

    ],
    "cc":[
        (
            'build : Changes that affect the build system or external dependencies (example scopes: gulp, broccoli, npm)',
            'build'
        ),
        (
            'ci : Changes to our CI configuration files and scripts (example scopes: Travis, Circle, BrowserStack, SauceLabs)',
            'ci'
        ),
        (
            'chore : Updates and changes',
            'chore'
        ),
        (
            'docs : Documentation only changes',
            'docs'
        ),
        (
            'feat : A new feature',
            'feat'
        ),
        (
            'fix : A bug fix',
            'fix'
        ),
        (
            'perf : A code change that improves performance',
            'perf'
        ),
        (
            'refactor : A code change that neither fixes a bug nor adds a feature',
            'refactor'
        ),
        (
            'revert: revert of the code',
            'revert'
        ),
        (
            'style : Changes that do not affect the meaning of the code (white-space, formatting, missing semi-colons, etc)',
            'style'
        ),
        (
            'test : Adding missing tests or correcting existing tests',
            'test'
        ),

    ]
}

def get_preselected_questions(format:str)-> list:
    question_list:list[PreselectedQuestion] = []

    preselected_questions_by_format:dict[str,dict] = {
        "cc": {
            "module": PreselectedQuestion("module", get_preselected_module)
        }
    }

    questions_to_search:dict[str,dict] = preselected_questions_by_format

    if format in questions_to_search:
        format_questions = questions_to_search[format]
        for question_to_make in format_questions:
            question_list.append(format_questions[question_to_make])

    return question_list

def get_questions(format:str, already_know_answers:list[str], optionals:bool = False) -> dict[str, list]:
    questions:list = []

    questions_by_format:dict[str,dict] ={
        "odoo": {
            "tag":      inquirer.List(name='tag', message='select the type of tag', choices=changes_choices_by_format[format] ),
            "module":   inquirer.Text(name='module', message="module name", validate=lambda _, x: x != '.'),
            "header":   inquirer.Text(name='header', message="header message", validate=lambda _, x: x != '.'),
            "body":     inquirer.Editor(name='body', message='body of the commit'),
            #inquirer.Confirm(name='correct',  message="tag: {tag}, module: {module} , header: {header} \n {body}\nContinue?", default=False),
        },
        "sgc":{
        },
        "cc":{
            "tag":      inquirer.List(name='tag', message='select the type', choices=changes_choices_by_format[format] ),
            "module":   inquirer.Text(name='module', message="scope", validate=lambda _, x: x != '.'),
            "header":   inquirer.Text(name='header', message="description", validate=lambda _, x: x != '.'),
        },
        "free":{
            "body":     inquirer.Editor(name='body', message='body of the commit'),
        }
    }

    optional_questions_by_format:dict[str, dict] = {
        "cc":{
            "body":     inquirer.Editor(name='body', message='body of the commit'),
            "footer":   inquirer.Editor(name='footer', message='footer of the commit'),
        }
    }

    questions_to_search:dict[str,dict] = questions_by_format if optionals is False else optional_questions_by_format

    if format in questions_to_search:
        format_questions = questions_to_search[format]
        for question_to_make in format_questions:
            if question_to_make not in already_know_answers:
                # print(f"adding : {question_to_make}")
                questions.append(format_questions[question_to_make])
    
    return {f"{format}": questions}



"""
@Author Marco A. Gallegos
@Date   2020/12/31
@Update 2020/12/31
@Description
    This file conatains a function to build a commit message using a
    terminal menu
"""
import os
from commitcli.commit_message import CommitMessage
from configmanager.config_manager import ConfigManager
import click
from common.logger import logger  

@click.command()
@click.option('-nop', '--nooptionals', required=False, is_flag=True, help='Do not ask for optional questions')
# @click.option(
#    '-f', '--format', required=False, help='Format the commit message',
#    # TODO: this need come from configuration file
#    type=click.Choice([], case_sensitive=False)
# )
@click.option('-log', '--onlylog', required=False, is_flag=True, help="Avoid confirmimg the message only make a lopg from the final message" )
def main(nooptionals: bool, onlylog: bool) -> bool:
    """Function to make commits, its a wrapper for the 'git commit' command
    this uses the '~/.commitclirc' file to store and manage the config.

    called by default for this module.

    :return: execution status
    :rtype: bool
    """
    logger.log("INFO", "Hello bby 7u7")
    forced_config:dict[str, bool] = {
        "avoid_optionals": nooptionals,
    }
    configuration_manager:ConfigManager = ConfigManager(override_config=forced_config, loadModuleManager=True)
    create_commit_message(configuration_manager, onlylog)


def create_commit_message(configuration_manager: ConfigManager, onlylog: bool) -> bool:
    commit_msg:CommitMessage = CommitMessage(configuration_manager=configuration_manager)
    are_there_changes:int = os.system("git status --short -uno >> /dev/null")
    if are_there_changes == 32768:
        print("there's not a git repository.")
        return False

    are_there_changes_output:str = os.popen("git diff --name-only --cached").read()  # str with the output
    if len(are_there_changes_output) == 0:
        print("looks like theres no changes to commit.")
        return False

    commit_msg.get_answers()
    commit_string:str|None = commit_msg.get_commit_string()

    if commit_string is None:
        return False

    print("commiting...")
    # print("=="*30)
    

    commit_command:str = f"git commit -m '{commit_string}'"

    if onlylog and onlylog is True:
        print(commit_command)
    else:
        os.system(commit_command)
    
    # update preselected files
    commit_msg.update_preselected_data()

    return True



"""
@Author Marco A. Gallegos
@Date   2020/12/31
@Update 2020/12/31
@Description
    Configuration is a class to contain and validate the configuration
"""
import os


class Configuration(object):
    config: dict = {
        "format": None,
        "signgpg": None,
        "avoid_optionals": False,
    }
    supported_formats: list = [
        "odoo",
        "sgc",
        "cc",
        "free",
    ]

    def __init__(self, config:dict = None, signgpg: bool = False, override_config: dict = None) -> None:
        self.config = {
            'format': "odoo",
            'signgpg': signgpg,
            'avoid_optionals': override_config['avoid_optionals'] if override_config else False
        }

        self.supported_formats = [
            "odoo",
            "sgc",
            "cc",
            "free",
        ]

        if config:
            self.config['format'] = config['format'].lower() if 'format' in config else self.config['format'].lower()
            self.config['signgpg'] = config['signgpg'] if 'signgpg' in config else self.config['signgpg']

            if self.config['signgpg'] and not self.can_sign_gpg():
                print("Tu configuracion solicita firmar commits pero git no esta configurado")
                self.config['signgpg']=False
            if not (self.config['format'] in self.supported_formats):
                print(
                    f"{self.config['format']} is not a supported format, instead we will use "
                    f"{self.supported_formats[0]} as default"
                )
                self.config['format'] = self.supported_formats[0]

        self.can_sign_gpg()
    
    def __str__(self)->str:
        """Return a string representation of the object, this function
        is called by the built in print function

        :return: string representation
        :rtype: str
        """
        return f"configuracion->  format: {self.config['format']} || sign: {self.config['signgpg']}" \
               f" || avoid_optionals: {self.config['avoid_optionals']}"
    
    def can_sign_gpg(self)->bool:
        """Return true if the users git repository is configured to sign the commits

        :return: indicates that the user can sign the commits
        :rtype: bool
        """
        signkey = os.popen("git config --global user.signingkey").read() 
        if not signkey :
            return False
        else:
            return True

    def is_a_valid_format(self, format: str) -> bool:
        """Return true if the format parameter string is a supported commit format.

        :param format: format to evaluate
        :type format: str
        :return: boolean if the format is supported
        :rtype: bool
        """
        return format in self.supported_formats


    def get_configuration_file_string(self, filled: bool = True) -> str:
        """This method returns the string to store the configuration file,
        optionally this function return the string template.

        :param filled: if you want the filled string or the template string, defaults to True
        :type filled: bool, optional
        :return: format string
        :rtype: str
        """
        file_template = "#Format for every commit\n"\
            "#supported formats free, odoo, sgc(semantic git commits) and cc (conventional commits)\n"\
            "format={format}\n\n"\
            "#Option to sign the commits o every commit, must be True or False\n"\
            "signgpg={sign}"\
        
        if filled:
            return file_template.format(format=self.config['format'], sign=self.config['signgpg'])
        else:
            return file_template



from io import TextIOWrapper
import pathlib
import os


class ModuleConfig(object):
    name:str
    date:int
    last_used:int
    use_count:int

    def __init__(self, name:str = None, date:int = 0, last_used:int = 0, use_count:int = 1) -> None:
        # print("constructing", [name, date, last_used, use_count])
        self.name:str = name
        self.date:int = date
        self.last_used:int =  last_used
        self.use_count:int = use_count
        # print("finish constructing")


    def __str__(self) -> str:
        return f"{self.name} {self.date} {self.last_used} {self.use_count}"



class ModuleManager(object):
    """
    File format
    """
    _file:str


    def __init__(self) -> None:
        self._file:str|None = ".ignore.commitcli_modules"
        self.load_modules()


    def current_file(self) -> str :
        """this function return the fullpath of the file to store
        the configuration

        :return: string with the full path of the file to
        :rtype: str
        """
        project_file = f"{pathlib.Path.cwd()}/{self._file}"
        return project_file if self.exist_file(project_file) else None


    def exist_file(self, file: str) -> bool:
        """this function returns a boolean value on true if the file
        to store the configuration

        :return: if the file exists on the filesystem
        :rtype: bool
        """
        exist = os.path.exists(file)
        return True if exist else False


    def load_modules(self) -> list[ModuleConfig]:
        current_file:str|None = self.current_file()

        if current_file is not None:
            modules_file:TextIOWrapper = open(current_file, "r")
            file_content:list[str] = modules_file.readlines()
            modules_file.close()
            moduleList:list = []

            for content in file_content:
                content_as_list:list[str] = content.replace("\n","").split(",")
                if len(content_as_list) >= 4:
                    # print(content_as_list[0], content_as_list[1], content_as_list[2], content_as_list[3])
                    try:
                        module:ModuleConfig = ModuleConfig(
                                content_as_list[0], int(content_as_list[1]),
                                int(content_as_list[2]), int(content_as_list[3])
                                )
                        moduleList.append(module)
                    except:
                        print("error parsing row", content_as_list)

            return moduleList
        return None


    def update_modules(self):
        pass


    def get_modules(self) -> list[ModuleConfig]:
        return self.load_modules()



if __name__ == "__main__":
    moduleManager:ModuleManager = ModuleManager()
    # row:ModuleConfig = ModuleConfig("tmti", 10, 9, 1)
    row:ModuleConfig = ModuleConfig()
    print("=="*100)
    #print(row)
    #print(moduleManager.get_modules())




"""
@Author Marco A. Gallegos
@Date   2020/12/31
@update 2022/04/04
@Description
    archivo que describe el paquete distribuible.
    how to use:
    compile ->  python3 setup.py sdist bdist_wheel
"""
import setuptools

with open("readme.md", "r") as fh:
    long_description = fh.read()
    fh.close()

setuptools.setup(
    name="commitcli",
    version="1.3.0-beta2",
    author="Marco A. Gallegos",
    author_email="ma_galeza@hotmail.com",
    description="commit cli for git with some formats, by default short version of odoo format",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/marco-gallegos/commit-cli",
    license="MIT",
    keywords="cli,cc,commit,git,odoo,github,gitlab,bitbucket,conventional commits, semantic commits",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
    install_requires=[
        'inquirer',
        'click',
        'loguru',
        'pendulum',
        'python-dotenv'
    ],
    # hacer que setup tools genere un comando cli
    entry_points={
        'console_scripts': ['commitcli=commitcli.commitcli:main'],
    }
)



from dotenv import load_dotenv
import os

load_dotenv()  # take environment variables from .env.

# Code of your application, which uses environment variables (e.g. from `os.environ` or
# `os.getenv`) as if they came from the actual environment.


class EnviromentConfiguration(object):

    def __init__(self) -> None:
        self.current_environment = "production"
        
        file_environment = os.getenv("environment")
        
        # print(file_environment)

        if file_environment :
            self.current_environment = file_environment

    def can_log_data(self) -> bool:
        should_log:bool = False if self.current_environment == "production" else True
        # print(f"should log {should_log}")
        return should_log


current_environment_configuration:EnviromentConfiguration = EnviromentConfiguration()



from loguru import logger 
from common.environment import current_environment_configuration
import sys

logger.remove()

if current_environment_configuration.can_log_data():
    # print("can lop data")
    logger.add(sys.stderr, level="INFO")


